@@ -189,8 +189,8 @@ class BaseBot:
             return await msg.reply(f'{cmd.fullname} is disabled for this channel')
 
         has_cooldown_bypass_permission = perms.has_permission(msg.channel_name, msg.author, cmd.cooldown_bypass)
-        if (not has_cooldown_bypass_permission and
-                is_command_on_cooldown(msg.channel_name, cmd.fullname, cmd.cooldown)):
+        if (not has_cooldown_bypass_permission
+                and is_command_on_cooldown(msg.channel_name, cmd.fullname, cmd.cooldown)):
             return await msg.reply(
                 f'{cmd.fullname} is on cooldown, seconds left: {cmd.cooldown - get_time_since_execute(msg.channel_name, cmd.fullname)}')
 
